@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 
+# 2014-02-14 to ignore cases for the sky prefix and to remove _ before the sky prefix
+
 import glob
 import os
 import sys
@@ -88,27 +90,32 @@ class readobslog():
 
     def __init__(self):
 
-        self.fnum=[]
-        self.oname=[]
-        self.itime=[]
-        self.raoff=[]
-        self.decoff=[]
-        self.ra=[]
-        self.dec=[]
+        self.fnum = []
+        self.oname = []
+        self.itime = []
+        self.raoff = []
+        self.decoff = []
+        self.ra = []
+        self.dec = []
 
-        f=open('obslog')
+        f = open('obslog')
         for line in f:
-            v=line.split()
+            v = line.split()
             if not re.match('flat', v[1], re.I) and not re.match('dark', v[1], re.I) and v[0].isdigit():
-                if v[2][-1:]=='.':
-                    v[2]=v[2][:-1]
-                    self.fnum.append(v[0])
-                    self.oname.append(v[1])
-                    self.itime.append(v[2])
-                    self.raoff.append(v[3])
-                    self.decoff.append(v[4])
-                    self.ra.append(v[11])
-                    self.dec.append(v[12])
+                if v[2][-1:] == '.':
+                    v[2] = v[2][:-1]
+                if re.search('sky$', v[1], re.I):      #  2014-02-14  to ignore cases for the sky prefix
+                    v[1] = v[1][:-3] + 'sky'           
+                if re.search('_sky$', v[1], re.I):     #  2014-02-14  to remove _ before the sky prefix
+                    v[1] = v[1][:-4] + 'sky'           
+
+                self.fnum.append(v[0])
+                self.oname.append(v[1])
+                self.itime.append(v[2])
+                self.raoff.append(v[3])
+                self.decoff.append(v[4])
+                self.ra.append(v[11])
+                self.dec.append(v[12])
 
         f.close()
 
@@ -202,7 +209,7 @@ def chkflat(band):
             hdulist.close()
 
     elif mflag == 1:
-        print 'the master flat will be used'
+        print 'the master flat frames are deployed'
         if band == 'all':
             os.system('ln -s %s/lib/jmflat.fits ./jmflat.fits' % SCRIPTDIR)
             os.system('ln -s %s/lib/hmflat.fits ./hmflat.fits' % SCRIPTDIR)
@@ -1520,6 +1527,10 @@ def clean(keepd, keeps, keepm):
     for file in glob.glob('*.skylist'):
         os.remove(file)
 
+    for file in glob.glob('*sky.list'):
+        os.remove(file)
+
+
     os.remove('0.ffiles')
 
 
