@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 
+#
+# 2014-04-01
+#   bkcheck : debug %%s -> %s 
 #
 # 2014-02-07 
 #   bkcheck() : the unstable messages are displayed only for the J-band
@@ -76,7 +79,7 @@ def bkcheck(band, mode, date, numarr, lvlarr):
         if lvlarr[i] - lvlarr[i-1] < 0 :
             flag += 1
             if band == 'j':
-                print 'background level unstable at %%s %s ' % (date, numarr[i-1])
+                print 'background level unstable at %s %s ' % (date, numarr[i-1]) 
                 print >> fw, 'background level unstable at %s %s ' % (date, numarr[i-1])
             print >> fo, '*'
         else:
